@@ -10,7 +10,7 @@ def test_temp_connection():
     receiver = lambda sender: canary.append(sender)
 
     sig.send(1)
-    with sig.temporarily_connected_to(receiver):
+    with sig.connected_to(receiver):
         sig.send(2)
     sig.send(3)
 
@@ -24,7 +24,7 @@ def test_temp_connection_for_sender():
     canary = []
     receiver = lambda sender: canary.append(sender)
 
-    with sig.temporarily_connected_to(receiver, sender=2):
+    with sig.connected_to(receiver, sender=2):
         sig.send(1)
         sig.send(2)
 
@@ -43,7 +43,7 @@ def test_temp_connection_failure():
 
     try:
         sig.send(1)
-        with sig.temporarily_connected_to(receiver):
+        with sig.connected_to(receiver):
             sig.send(2)
             raise Failure
         sig.send(3)
